'use strict';

var _tester = require('tester');

var _tester2 = _interopRequireDefault(_tester);

var _angular = require('angular');

var _angular2 = _interopRequireDefault(_angular);

require('../exceptions');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('avExceptionAnalyticsProvider', function () {

  var provider = void 0;
  var service = void 0;
  var $exceptionHandler = void 0;
  var $q = void 0;

  var tester = new _tester2.default();
  tester.provider();

  beforeEach(_angular2.default.mock.module('availity'));

  beforeEach(_angular2.default.mock.module(function (avExceptionAnalyticsProvider, $exceptionHandlerProvider) {
    provider = avExceptionAnalyticsProvider;
    $exceptionHandlerProvider.mode('log');
  }));

  beforeEach(inject(function (avExceptionAnalytics, _$exceptionHandler_, _$q_) {

    service = avExceptionAnalytics;
    $exceptionHandler = _$exceptionHandler_;
    $q = _$q_;

    spyOn(service, 'trackEvent').and.callThrough();
    spyOn(service, 'onError').and.callThrough();
    spyOn(service, 'log').and.callFake(function (message) {
      return $q.when(message);
    });
  }));

  it('should be defined', function () {

    expect(provider.$get).toBeDefined();
    expect(provider.enabled).toBeDefined();
    expect(provider.setAppId).toBeDefined();
  });

  describe('avExceptionAnalytics', function () {

    var exception = void 0;

    beforeEach(function () {

      try {
        throw new Error('mock error');
      } catch (e) {
        exception = e;
      }
    });

    it('should track exception event', function () {

      $exceptionHandler(exception);
      expect(service.trackEvent).toHaveBeenCalled();
      expect(service.onError).toHaveBeenCalled();
      expect(service.log).toHaveBeenCalled();

      var message = service.log.calls.mostRecent().args[0];

      expect(message.errorName).toBe('Error');
      expect(message.errorMessage).toBe('mock error');
    });

    it('should not track rapid exceptions more than once', function () {

      $exceptionHandler(exception);
      $exceptionHandler(exception);
      expect(service.trackEvent.calls.count()).toEqual(2);
      expect(service.onError.calls.count()).toEqual(1);
      expect(service.log.calls.count()).toEqual(1);
    });
  });
}); /* global it, spyOn, inject, module, beforeEach, expect, describe */