'use strict';

var _angular = require('angular');

var _angular2 = _interopRequireDefault(_angular);

var _tester = require('tester');

var _tester2 = _interopRequireDefault(_tester);

var _provider = require('../provider');

var _provider2 = _interopRequireDefault(_provider);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('avAnalyticsProvider', function () {

  var avAnalyticsProvider = void 0;
  var avAnalytics = void 0;
  var analyticsPlugin = void 0;
  var q = void 0;
  var $rootScope = void 0;

  var tester = new _tester2.default();
  tester.provider();

  beforeEach(_angular2.default.mock.module(_provider2.default.name));

  beforeEach(_angular2.default.mock.module(function (_avAnalyticsProvider_, $provide) {

    // Fake analytics plugin
    analyticsPlugin = {
      trackEvent: function trackEvent() {
        return q.when(true);
      },
      trackPageView: function trackPageView() {
        return q.when(true);
      },
      isEnabled: function isEnabled() {
        return true;
      },
      init: function init() {}
    };

    spyOn(analyticsPlugin, 'trackEvent').and.callThrough();
    spyOn(analyticsPlugin, 'trackPageView').and.callThrough();
    spyOn(analyticsPlugin, 'init');
    $provide.value('analyticsPlugin', analyticsPlugin);

    avAnalyticsProvider = _avAnalyticsProvider_;
    // Register fake plugin
    avAnalyticsProvider.registerPlugins('analyticsPlugin');
  }));

  beforeEach(inject(function (_avAnalytics_, $q, _$rootScope_) {

    avAnalytics = _avAnalytics_;
    q = $q;
    $rootScope = _$rootScope_;
  }));

  it('should be defined', function () {

    expect(avAnalyticsProvider.$get).toBeDefined();
    expect(avAnalyticsProvider.registerPlugins).toBeDefined();
    expect(avAnalyticsProvider.setVirtualPageTracking).toBeDefined();
    expect(avAnalyticsProvider.isVirtualPageTracking).toBeDefined();
    expect(avAnalyticsProvider.setAppID).toBeDefined();
  });

  describe('avAnalytics', function () {

    it('should call trackEvent() for each registered plugin', function () {

      avAnalytics.trackEvent({});
      tester.flush();

      expect(analyticsPlugin.trackEvent).toHaveBeenCalled();
    });

    it('should call trackPageView() for each registered plugin', function () {

      avAnalytics.trackPageView({});
      tester.flush();

      expect(analyticsPlugin.trackPageView).toHaveBeenCalled();
    });

    it('should trackPageView() on route change', function () {

      avAnalyticsProvider.setVirtualPageTracking(true);
      avAnalytics.init();

      $rootScope.$broadcast('$locationChangeSuccess');

      $rootScope.$digest();
      expect(analyticsPlugin.trackPageView).toHaveBeenCalled();
    });

    it('should call init()', function () {
      avAnalytics.init();
      expect(analyticsPlugin.init).toHaveBeenCalled();
    });
  });
}); /* global inject, spyOn, it, expect, describe, beforeEach */