'use strict';

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _angular = require('angular');

var _angular2 = _interopRequireDefault(_angular);

var _resource = require('../resource');

var _resource2 = _interopRequireDefault(_resource);

var _tester = require('tester');

var _tester2 = _interopRequireDefault(_tester);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; } /* global describe, spyOn, inject, beforeEach, afterEach, it, expect, jasmine, module */

describe('AvApiResourceProvider', function () {

  _tester2.default.matchers();

  describe('AvApiResource', function () {

    var $httpBackend = void 0;
    var $q = void 0;
    var AvApiResource = void 0;
    var callback = void 0;

    var responseData = [{ a: 1, b: 2 }, { a: 1, b: 2 }];
    var mockStorageVal = 'fakeStorageVal';

    beforeEach(function () {

      callback = jasmine.createSpy('done');

      _angular2.default.mock.module(_resource2.default.name);

      _angular2.default.mock.module(function ($provide) {

        var pollingService = {
          response: function response(_response) {
            return _response || $q.when(_response);
          }
        };

        $provide.value('avPollingService', pollingService);
      });

      inject(function (_$httpBackend_, _$q_, _AvApiResource_, avLocalStorageService) {
        $httpBackend = _$httpBackend_;
        $q = _$q_;
        AvApiResource = _AvApiResource_;
        spyOn(avLocalStorageService, 'getVal').and.returnValue(mockStorageVal);
      });
    });

    afterEach(function () {
      $httpBackend.verifyNoOutstandingExpectation();
      $httpBackend.verifyNoOutstandingRequest();
    });

    it('should not allow options to be null', function () {
      expect(function () {
        return new AvApiResource();
      }).toThrow(new Error('[options] cannot be null or undefined'));
    });

    describe('urls', function () {

      it('should build url with resource name', function () {

        var cats = new AvApiResource({ name: 'cats' });

        expect(cats).toBeObject();
        expect(cats.getUrl()).toBe('/api/v1/cats');
      });

      it('should build url with resource name and forward slash', function () {

        var cats = new AvApiResource({ name: '/cats' });
        expect(cats.getUrl()).toBe('/api/v1/cats');
      });

      it('should build url with resource name and path', function () {

        var cats = new AvApiResource({
          path: '/internal/api',
          name: '/cats'
        });

        expect(cats.getUrl()).toBe('/internal/api/v1/cats');
      });

      it('should build url with with resource name, version and path', function () {

        var cats = new AvApiResource({
          version: '/v2',
          name: '/bar',
          path: '/api/foo'
        });

        expect(cats.getUrl()).toBe('/api/foo/v2/bar');
      });

      it('should build url with missing slash "/" character', function () {

        var api = new AvApiResource({
          version: 'v1',
          name: 'bar',
          path: 'api/foo'
        });

        expect(api.getUrl()).toBe('/api/foo/v1/bar');
      });

      it('should build url', function () {

        var cats = new AvApiResource({
          url: '/availity/login',
          api: false
        });

        expect(cats.getUrl()).toBe('/availity/login');
      });
    });

    describe('rest', function () {

      var cats = void 0;

      beforeEach(function () {
        cats = new AvApiResource({ name: 'cats', sessionBust: false });
      });

      describe('query()', function () {

        it('should get list of resources', function () {

          // expectGET to make sure this is called once.
          $httpBackend.expectGET('/api/v1/cats').respond(200, responseData);

          cats.query().success(function (data) {
            expect(data).toBeEqual(responseData);
          });

          $httpBackend.flush();
        });

        it('should get list of resources with params', function () {

          // expectGET to make sure this is called once.
          $httpBackend.expectGET('/api/v1/cats?a=1&b=2').respond(200, responseData);

          cats.query({ params: { a: 1, b: 2 } }).success(function (data) {
            expect(data).toBeEqual(responseData);
            callback();
          });

          $httpBackend.flush();
          expect(callback).toHaveBeenCalled();
        });

        it('should have a cacheBust parameter when cacheBust is true', function () {

          $httpBackend.expectGET(/\/api\/v1\/cats\?cacheBust=\d+/).respond(200, responseData);

          cats.query({ cacheBust: true }).success(function (data) {
            expect(data).toBeEqual(responseData);
            callback();
          });

          $httpBackend.flush();
          expect(callback).toHaveBeenCalled();
        });

        it('should have a cacheBust parameter when cacheBust is value', function () {

          $httpBackend.expectGET(/\/api\/v1\/cats\?cacheBust=hello/).respond(200, responseData);

          cats.query({ cacheBust: 'hello' }).success(function (data) {
            expect(data).toBeEqual(responseData);
            callback();
          });

          $httpBackend.flush();
          expect(callback).toHaveBeenCalled();
        });

        it('should have a cacheBust parameter when cacheBust is a function', function () {

          $httpBackend.expectGET(/\/api\/v1\/cats\?cacheBust=hello/).respond(200, responseData);

          var cacheBustFn = jasmine.createSpy('cacheBustFn').and.returnValue('hello');

          cats.query({ cacheBust: cacheBustFn }).success(function (data) {
            expect(data).toBeEqual(responseData);
            expect(cacheBustFn).toHaveBeenCalled();
            callback();
          });

          $httpBackend.flush();
          expect(callback).toHaveBeenCalled();
        });

        it('should have a cacheBust parameter with other parameters', function () {

          $httpBackend.expectGET(/\/api\/v1\/cats\?a=1&b=2&cacheBust=\d+/).respond(200, responseData);

          cats.query({ params: { a: 1, b: 2 }, cacheBust: true }).success(function (data) {
            expect(data).toBeEqual(responseData);
            callback();
          });

          $httpBackend.flush();
          expect(callback).toHaveBeenCalled();
        });

        it('should have a pageBust parameter when pageBust is true', function () {

          $httpBackend.expectGET(/\/api\/v1\/cats\?pageBust=\d+/).respond(200, responseData);

          cats.query({ pageBust: true }).success(function (data) {
            expect(data).toBeEqual(responseData);
            callback();
          });

          $httpBackend.flush();
          expect(callback).toHaveBeenCalled();
        });

        it('should have a sessionBust parameter when sessionBust is true', function () {

          $httpBackend.expectGET('/api/v1/cats?sessionBust=' + mockStorageVal).respond(200, responseData);

          cats.query({ sessionBust: true }).success(function (data) {
            expect(data).toBeEqual(responseData);
            callback();
          });

          $httpBackend.flush();
          expect(callback).toHaveBeenCalled();
        });
      });

      describe('create()', function () {
        it('should post a single resource', function () {
          $httpBackend.expectPOST('/api/v1/cats').respond(200, responseData);

          cats.create({}).success(function (data) {
            expect(data).toBeEqual(responseData);
            callback();
          });
          $httpBackend.flush();
          expect(callback).toHaveBeenCalled();
        });
      });

      describe('postGet()', function () {
        it('should post a single resource with GET override', function () {
          $httpBackend.expectPOST('/api/v1/cats').respond(200, responseData);

          var request = spyOn(cats, 'request').and.callThrough();

          var data = { id: 1 };
          var config = { headers: { 'MyHeader': 'MyValue' } };
          cats.postGet(data, config).success(function (result) {
            expect(result).toBeEqual(responseData);
            callback();
          });

          $httpBackend.flush();
          expect(callback).toHaveBeenCalled();

          config = cats.config(config);
          config.method = 'POST';
          config.headers['X-HTTP-Method-Override'] = 'GET';
          config.url = cats.getUrl();
          config.data = data;

          expect(request).toHaveBeenCalled();
          expect(request).toHaveBeenCalledWith(config, jasmine.any(Function));
        });
      });

      describe('get()', function () {

        it('should get a single resource by id', function () {

          $httpBackend.expectGET('/api/v1/cats/1').respond(200, responseData);

          cats.get(1).success(function (data) {
            expect(data).toBeEqual(responseData);
            callback();
          });

          $httpBackend.flush();
          expect(callback).toHaveBeenCalled();
        });

        it('should have a cacheBust parameter when cacheBust is true', function () {

          $httpBackend.expectGET(/\/api\/v1\/cats\/1\?cacheBust=\d+/).respond(200, responseData);

          cats.get(1, { cacheBust: true }).success(function (data) {
            expect(data).toBeEqual(responseData);
            callback();
          });

          $httpBackend.flush();
          expect(callback).toHaveBeenCalled();
        });
      });

      describe('update()', function () {

        var updateResponseData = { id: 1, foo: 'bar' };

        it('should update a single resource by id', function () {

          $httpBackend.expectPUT('/api/v1/cats/1').respond(200, updateResponseData);

          cats.update(1, {}).success(function (data) {
            expect(data).toBeEqual(updateResponseData);
            callback();
          });

          $httpBackend.flush();
          expect(callback).toHaveBeenCalled();
        });

        it('should update a single resource WITHOUT an id', function () {

          $httpBackend.expectPUT('/api/v1/cats').respond(200, updateResponseData);

          var request = spyOn(cats, 'request').and.callThrough();

          var data = { id: 1 };
          var config = { headers: { 'MyHeader': 'MyValue' } };
          cats.update(data, config).success(function (result) {
            expect(result).toBeEqual(updateResponseData);
            callback();
          });

          $httpBackend.flush();
          expect(callback).toHaveBeenCalled();

          config = cats.config(config);
          config.method = 'PUT';
          config.url = cats.getUrl();
          config.data = data;

          expect(request).toHaveBeenCalled();
          expect(request).toHaveBeenCalledWith(config, jasmine.any(Function));
        });
      });

      describe('remove()', function () {

        it('should remove resource WITHOUT an id', function () {

          $httpBackend.expectDELETE('/api/v1/cats').respond({});

          var request = spyOn(cats, 'request').and.callThrough();

          var data = { id: 1 };
          var config = { headers: { 'MyHeader': 'MyValue' } };
          cats.remove(data, config);

          $httpBackend.flush();

          config = cats.config(config);
          config.method = 'DELETE';
          config.url = cats.getUrl();
          config.data = data;

          expect(request).toHaveBeenCalled();
          expect(request).toHaveBeenCalledWith(config, jasmine.any(Function));
        });
      });
    });

    describe('callbacks', function () {

      beforeEach(function () {});

      it('should call afterGet() on get()', function () {
        var Cats = function (_AvApiResource) {
          _inherits(Cats, _AvApiResource);

          function Cats() {
            _classCallCheck(this, Cats);

            return _possibleConstructorReturn(this, (Cats.__proto__ || Object.getPrototypeOf(Cats)).call(this, { name: '/cats', sessionBust: false }));
          }

          _createClass(Cats, [{
            key: 'afterGet',
            value: function afterGet(response) {
              response.data[0].a = 2;
              return response;
            }
          }]);

          return Cats;
        }(AvApiResource);

        var cats = new Cats();
        spyOn(cats, 'afterGet').and.callThrough();
        $httpBackend.expectGET('/api/v1/cats/1').respond(200, responseData);

        cats.get(1).success(function (data) {
          return expect(data).toBeEqual([{ a: 2, b: 2 }, { a: 1, b: 2 }]);
        });
        $httpBackend.flush();

        expect(cats.afterGet).toHaveBeenCalled();
        expect(cats.afterGet.calls.count()).toEqual(1);
      });

      it('should call afterQuery() on query()', function () {
        var Cats = function (_AvApiResource2) {
          _inherits(Cats, _AvApiResource2);

          function Cats() {
            _classCallCheck(this, Cats);

            return _possibleConstructorReturn(this, (Cats.__proto__ || Object.getPrototypeOf(Cats)).call(this, { name: '/cats', sessionBust: false }));
          }

          _createClass(Cats, [{
            key: 'afterQuery',
            value: function afterQuery(response) {
              return response;
            }
          }]);

          return Cats;
        }(AvApiResource);

        var cats = new Cats();
        var queryCallback = spyOn(cats, 'afterQuery').and.callThrough();
        $httpBackend.expectGET('/api/v1/cats').respond(200, responseData);

        cats.query();
        $httpBackend.flush();

        expect(queryCallback).toHaveBeenCalled();
        expect(queryCallback.calls.count()).toEqual(1);
      });

      it('should call beforeCreate() and afterCreate() on create()', function () {

        $httpBackend.expectPOST('/api/v1/cats').respond(200, responseData);

        var Cats = function (_AvApiResource3) {
          _inherits(Cats, _AvApiResource3);

          function Cats() {
            _classCallCheck(this, Cats);

            return _possibleConstructorReturn(this, (Cats.__proto__ || Object.getPrototypeOf(Cats)).call(this, { name: '/cats' }));
          }

          _createClass(Cats, [{
            key: 'beforeCreate',
            value: function beforeCreate(data) {
              return data;
            }
          }, {
            key: 'afterCreate',
            value: function afterCreate(response) {
              return response;
            }
          }]);

          return Cats;
        }(AvApiResource);

        var cats = new Cats();
        var beforeCreateCallback = spyOn(cats, 'beforeCreate').and.callThrough();
        var afterCreateCallback = spyOn(cats, 'afterCreate').and.callThrough();

        var data = {
          'firstName': 'Rob',
          'lastName': 'McGuinness'
        };

        cats.create(data);
        $httpBackend.flush();

        expect(beforeCreateCallback).toHaveBeenCalled();
        expect(beforeCreateCallback).toHaveBeenCalledWith(data);
        expect(beforeCreateCallback.calls.count()).toEqual(1);

        expect(afterCreateCallback).toHaveBeenCalled();
        expect(afterCreateCallback.calls.argsFor(0).length).toEqual(2); //
        expect(afterCreateCallback.calls.argsFor(0)[1]).toEqual(data); //
        expect(afterCreateCallback.calls.count()).toEqual(1);
      });

      it('should call afterRemove() on remove()', function () {

        $httpBackend.expectDELETE('/api/v1/cats/1').respond(200, responseData);

        var Cats = function (_AvApiResource4) {
          _inherits(Cats, _AvApiResource4);

          function Cats() {
            _classCallCheck(this, Cats);

            return _possibleConstructorReturn(this, (Cats.__proto__ || Object.getPrototypeOf(Cats)).call(this, { name: '/cats' }));
          }

          _createClass(Cats, [{
            key: 'afterRemove',
            value: function afterRemove(response) {
              return response;
            }
          }]);

          return Cats;
        }(AvApiResource);

        var cats = new Cats();
        var afterRemoveCallback = spyOn(cats, 'afterRemove').and.callThrough();

        cats.remove(1);
        $httpBackend.flush();

        expect(afterRemoveCallback).toHaveBeenCalled();
        expect(afterRemoveCallback.calls.count()).toEqual(1);
      });

      it('should call beforeUpdate() and afterUpdate() on update()', function () {

        $httpBackend.whenPUT('/api/v1/cats/1').respond(200, responseData);

        var Cats = function (_AvApiResource5) {
          _inherits(Cats, _AvApiResource5);

          function Cats() {
            _classCallCheck(this, Cats);

            return _possibleConstructorReturn(this, (Cats.__proto__ || Object.getPrototypeOf(Cats)).call(this, { name: '/cats' }));
          }

          _createClass(Cats, [{
            key: 'beforeUpdate',
            value: function beforeUpdate(data) {
              return data;
            }
          }, {
            key: 'afterUpdate',
            value: function afterUpdate(response) {
              return response;
            }
          }]);

          return Cats;
        }(AvApiResource);

        var cats = new Cats();
        var beforeUpdateCallback = spyOn(cats, 'beforeUpdate').and.callThrough();
        var afterUpdateCallback = spyOn(cats, 'afterUpdate').and.callThrough();

        var data = {
          'firstName': 'Rob',
          'lastName': 'McGuinness'
        };

        cats.update(1, data);

        $httpBackend.flush();

        expect(beforeUpdateCallback).toHaveBeenCalled();
        expect(beforeUpdateCallback).toHaveBeenCalledWith(data);
        expect(beforeUpdateCallback.calls.count()).toEqual(1);

        expect(afterUpdateCallback).toHaveBeenCalled();
        expect(afterUpdateCallback.calls.count()).toEqual(1);
      });
    });
  });
});