'use strict';

var _angular = require('angular');

var _angular2 = _interopRequireDefault(_angular);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('avLocalStorageService', function () {

  var avLocalStorageService = void 0;
  var $window = void 0;
  var mockLocalStorage = void 0;

  beforeEach(function () {
    _angular2.default.mock.module('availity');

    mockLocalStorage = {};
    _angular2.default.mock.module(function ($provide) {
      $provide.value('$window', {
        localStorage: {
          getItem: function getItem(key) {
            return mockLocalStorage[key] || null;
          },
          setItem: function setItem(key, value) {
            mockLocalStorage[key] = value + '';
          },
          removeItem: function removeItem(key) {
            delete mockLocalStorage[key];
          },
          get length() {
            return Object.keys(mockLocalStorage).length;
          },
          key: function key(i) {
            var keys = Object.keys(mockLocalStorage);
            return keys[i] || null;
          }
        }
      });
    });

    inject(function (_avLocalStorageService_, _$window_) {
      avLocalStorageService = _avLocalStorageService_;
      $window = _$window_;
    });
  });

  it('should exist', function () {
    expect(avLocalStorageService).toBeDefined();
  });

  describe('localStorage supported', function () {

    it('should return true', function () {
      expect(avLocalStorageService.supportsLocalStorage()).toBeTruthy();
    });

    it('should return false if localStorage does not exist', function () {
      $window.localStorage = undefined;
      expect(avLocalStorageService.supportsLocalStorage()).not.toBeTruthy();
    });

    it('should return false if localStorage functions throw error', function () {
      spyOn($window.localStorage, 'getItem').and.callFake(function () {
        throw new Error('mock error');
      });
      expect(avLocalStorageService.supportsLocalStorage()).toBeFalsy();
    });
  });

  it('should set and retrieve correct values', function () {
    expect(avLocalStorageService.supportsLocalStorage()).toBeTruthy();
    var testVal = 'testVal';
    avLocalStorageService.setVal(testVal, testVal);
    expect(avLocalStorageService.getVal(testVal)).toEqual(testVal);
  });

  it('should remove all keys that match regex test', function () {
    expect(avLocalStorageService.supportsLocalStorage()).toBeTruthy();
    avLocalStorageService.setVal('testVal1', 1);
    avLocalStorageService.setVal('testVal2', 2);
    avLocalStorageService.setVal('testVal3', 3);
    avLocalStorageService.setVal('otherVal', 4);

    expect(avLocalStorageService.getVal('testVal1')).toBeDefined();
    expect(avLocalStorageService.getVal('testVal2')).toBeDefined();
    expect(avLocalStorageService.getVal('testVal3')).toBeDefined();
    expect(avLocalStorageService.getVal('otherVal')).toBeDefined();

    avLocalStorageService.removeKeys('testVal');

    expect(avLocalStorageService.getVal('testVal1')).toBeNull();
    expect(avLocalStorageService.getVal('testVal2')).toBeNull();
    expect(avLocalStorageService.getVal('testVal3')).toBeNull();
    expect(avLocalStorageService.getVal('otherVal')).toBeDefined();
  });
}); /* global inject, describe, beforeEach, it, expect, module, spyOn */