'use strict';

var _angular = require('angular');

var _angular2 = _interopRequireDefault(_angular);

var _jquery = require('jquery');

var _jquery2 = _interopRequireDefault(_jquery);

var _tester = require('tester');

var _tester2 = _interopRequireDefault(_tester);

require('../');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* global it, inject, jasmine, module, spyOn, beforeEach, expect, describe */

describe('avMessagesProvider', function () {

  var avMessagesProvider = void 0;
  var $rootScope = void 0;
  var avMessages = void 0;
  var AV_MESSAGES = void 0;

  var tester = new _tester2.default();
  tester.provider();

  beforeEach(_angular2.default.mock.module('availity', function (_avMessagesProvider_) {

    avMessagesProvider = _avMessagesProvider_;
    avMessagesProvider.enable(false);
  }));

  beforeEach(inject(function (_$rootScope_, _avMessages_, _AV_MESSAGES_) {
    $rootScope = _$rootScope_;
    avMessages = _avMessages_;
    AV_MESSAGES = _AV_MESSAGES_;
  }));

  it('should be defined', function () {
    expect(avMessagesProvider.$get).toBeDefined();
    expect(avMessagesProvider.enable).toBeDefined();
  });

  describe('avMessages', function () {

    function testDomain(domain) {
      avMessages.domain = jasmine.createSpy().and.returnValue(domain);
      expect(avMessages.isDomain(domain)).toBeTruthy();
    }

    it('regex should validate availity.com domains', function () {

      testDomain('https://availity.com');
      testDomain('https://availity.com');
      testDomain('https://www.availity.com');
      testDomain('https://apps.availity.com');
      testDomain('https://test-apps.availity.com');
      testDomain('https://availity.net');

      testDomain('http://localhost:3000');
      testDomain('http://0.0.0.0:3000');
      testDomain('http://127.0.0.1:3000');
    });

    it('should send AV_RESIZE when window is resized', function () {

      avMessages.init();
      var flush = avMessages.onResize.flush;

      spyOn(avMessages, 'onResize').and.callThrough();
      spyOn(avMessages, 'send');

      window.scroll(0, 1000);
      (0, _jquery2.default)(window).trigger('resize');

      flush();

      expect(avMessages.send).toHaveBeenCalled();

      var payload = avMessages.send.calls.mostRecent().args[0];
      expect(payload.event).toBe(AV_MESSAGES.EVENTS.AV_RESIZE);
      expect(payload.height).toBeDefined();

      avMessages.destroy();
    });

    it('send() should post string event', function () {

      spyOn(avMessages, 'postMessage');
      avMessages.send('hipaa');
      expect(avMessages.postMessage).toHaveBeenCalledWith('hipaa', jasmine.any(String));
    });

    it('send() should post object event', function () {

      spyOn(avMessages, 'postMessage');

      avMessages.send({ event: 'resize', height: '45px' });

      expect(avMessages.postMessage).toHaveBeenCalledWith('{"event":"resize","height":"45px"}', jasmine.any(String));
    });

    it('onMessage() should emit string event', function () {

      spyOn($rootScope, '$broadcast');

      avMessages.onMessage({
        origin: 'http://localhost:9876',
        data: 'window:resize'
      });

      expect($rootScope.$broadcast).toHaveBeenCalledWith('window:resize', null);
    });

    it('onMessage() should emit string event and object', function () {

      spyOn($rootScope, '$broadcast');

      avMessages.onMessage({
        origin: 'http://localhost:9876',
        data: '{"event":"window:resize","height":"45px"}'
      });

      expect($rootScope.$broadcast).toHaveBeenCalledWith('window:resize', { 'event': 'window:resize', 'height': '45px' });
    });
  });
});