'use strict';

var _angular = require('angular');

var _angular2 = _interopRequireDefault(_angular);

require('../date-range');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* global describe, it, sinon, beforeEach, afterEach, expect, module, inject */

describe('avValDateRange', function () {

  var dateRange = void 0;
  var rules = void 0;
  var rulesFromTo = void 0;
  var clock = void 0;

  beforeEach(_angular2.default.mock.module('availity'));

  beforeEach(inject(function (avValDateRange) {

    clock = sinon.useFakeTimers(new Date(2015, 4, 15).getTime());

    dateRange = avValDateRange;

    rules = {
      'start': {
        'value': '-1',
        'units': 'days'
      },
      'end': {
        'value': '1',
        'units': 'months'
      },
      'format': 'MMDDYYYY',
      'message': 'Date Range is not correct.'
    };

    rulesFromTo = {
      'start': {
        'value': '05022015'
      },
      'end': {
        'value': '05152015'
      },
      'format': 'MMDDYYYY',
      'message': 'Date Range is not correct.'
    };
  }));

  afterEach(function () {
    clock.restore();
  });

  it('should be a valid', function () {

    // Fake today set to 05152015
    expect(dateRange.validate({ value: '05142015', constraint: rules })).toBe(true);
    expect(dateRange.validate({ value: '06142015', constraint: rules })).toBe(true);
    expect(dateRange.validate({ value: '05022015', constraint: rulesFromTo })).toBe(true);
    expect(dateRange.validate({ value: '05052015', constraint: rulesFromTo })).toBe(true);
  });

  it('should be a invalid', function () {

    // Fake today set to 05152015
    expect(dateRange.validate({ value: '04292015', constraint: rules })).toBe(false);
    expect(dateRange.validate({ value: '05132015', constraint: rules })).toBe(false);
    expect(dateRange.validate({ value: '06292015', constraint: rules })).toBe(false);
    expect(dateRange.validate({ value: '05012015', constraint: rulesFromTo })).toBe(false);
    expect(dateRange.validate({ value: '05162015', constraint: rulesFromTo })).toBe(false);

    // Format Checks
    expect(dateRange.validate({ value: '04452015', constraint: rules })).toBe(false);
    expect(dateRange.validate({ value: '04462015', constraint: rules })).toBe(false);
    expect(dateRange.validate({ value: '04472015', constraint: rules })).toBe(false);
    expect(dateRange.validate({ value: '17132014', constraint: rulesFromTo })).toBe(false);
    expect(dateRange.validate({ value: '17142014', constraint: rulesFromTo })).toBe(false);
  });
});