'use strict';

var _angular = require('angular');

var _angular2 = _interopRequireDefault(_angular);

require('../npi');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* global describe, it, beforeEach, expect, module, inject*/

describe('avValNpi', function () {

  var avValNpi = void 0;

  beforeEach(_angular2.default.mock.module('availity'));

  beforeEach(inject(function (_avValNpi_) {
    avValNpi = _avValNpi_;
  }));

  it('should validate if NPI is empty, undefined or null', function () {
    expect(avValNpi.validate({ value: undefined })).toBe(true);
    expect(avValNpi.validate({ value: '' })).toBe(true);
    expect(avValNpi.validate({ value: null })).toBe(true);
  });

  it('should NOT validate if NPI contains non-digits', function () {
    expect(avValNpi.validate({ value: 'i2eh56789o' })).toBe(false);
  });

  it('should NOT validate if NPI is not 10 digits in length', function () {
    expect(avValNpi.validate({ value: '123456789' })).toBe(false);
    expect(avValNpi.validate({ value: '12345678901' })).toBe(false);
  });

  it('should NOT validate if NPI does not start with a 1, 2, 3, or 4', function () {
    expect(avValNpi.validate({ value: '5678901234' })).toBe(false);
  });

  it('should NOT validate if NPI checksum does not match check digit', function () {
    expect(avValNpi.validate({ value: '1234567890' })).toBe(false);
  });

  it('should validate if NPI is valid', function () {
    expect(avValNpi.validate({ value: '1234567893' })).toBe(true);
  });
});