'use strict';

var _angular = require('angular');

var _angular2 = _interopRequireDefault(_angular);

var _tester = require('tester');

var _tester2 = _interopRequireDefault(_tester);

require('../');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('avAnalytics', function () {

  var avAnalytics = void 0;
  var analyticsController = void 0;

  var tester = new _tester2.default();

  beforeEach(_angular2.default.mock.module('availity', 'availity.ui'));

  tester.directive();

  beforeEach(inject(function (_avAnalytics_, $q) {
    avAnalytics = _avAnalytics_;
    spyOn(avAnalytics, 'trackEvent').and.callFake(function () {
      return $q.when(true);
    });
  }));

  beforeEach(inject(function ($rootScope, $controller) {
    analyticsController = $controller('AvAnalyticsController', { $scope: {} });
  }));

  describe('controller', function () {

    var mockEvent = {
      type: 'click',
      preventDefault: jasmine.createSpy(),
      stopPropagation: jasmine.createSpy()
    };

    var mockElement = {
      text: function text() {
        return 'mockElement';
      }
    };

    var mockOptions = {};

    it('onEvent should be defined', function () {
      expect(analyticsController.onEvent).toBeDefined();
    });

    it('label should be info if not defined', function () {
      mockOptions = {};
      analyticsController.onEvent(mockEvent, mockElement, mockOptions);
      expect(avAnalytics.trackEvent).toHaveBeenCalledWith({ event: 'click', level: 'info', label: 'mockElement' });
    });

    it('options should override values from event/element', function () {
      mockOptions = {
        event: 'testEvent',
        level: 'testLevel',
        label: 'testLabel'
      };
      analyticsController.onEvent(mockEvent, mockElement, mockOptions);
      expect(avAnalytics.trackEvent).toHaveBeenCalledWith({ event: 'testEvent', level: 'testLevel', label: 'testLabel' });
    });
  });

  describe('directives', function () {

    it('should have directive', function () {
      var el = tester.compileDirective('<div data-av-analytics="{ \'category\': \'testCategory\'}"></div>');
      expect(el.data('$avAnalyticsController')).toBeDefined();
    });

    it('should have on-directive', function () {
      var el = tester.compileDirective('<div data-av-analytics-on="click"></div>');
      expect(el.data('$avAnalyticsOnController')).toBeDefined();
    });

    it('should pass data down to on-directive', function () {
      var el = tester.compileDirective('<div data-av-analytics="{ \'category\': \'testCategory\'}"><div data-av-analytics-on="click">Test</div></div>');
      el.children().trigger('click');
      tester.flush();
      expect(avAnalytics.trackEvent).toHaveBeenCalledWith({ event: 'click', level: 'info', label: 'Test', category: 'testCategory' });
    });

    it('defining event overrides actual event type', function () {
      var el = tester.compileDirective('<div data-av-analytics="{ \'category\': \'testCategory\'}"><div data-av-analytics-on="click" data-av-analytics-event="play">Test</div></div>');
      el.children().trigger('click');
      tester.flush();
      expect(avAnalytics.trackEvent).toHaveBeenCalledWith({ event: 'play', level: 'info', label: 'Test', category: 'testCategory' });
    });

    it('should allow static label', function () {
      tester.$scope.label = 'Testing';
      var $el = tester.compileDirective('<div><div data-av-analytics-on="click" data-av-analytics-label="{{label}}"></div></div>');
      var controller = $el.children().data('$avAnalyticsOnController');

      spyOn(controller, 'onEvent').and.callThrough();

      $el.children().trigger('click');
      tester.flush();
      expect(controller.onEvent).toHaveBeenCalled();
      expect(avAnalytics.trackEvent).toHaveBeenCalledWith({ event: 'click', level: 'info', label: 'Testing' });
    });

    it('should allow dynamic label', function () {
      tester.$scope.label = 'Testing';
      var $el = tester.compileDirective('<div><div data-av-analytics-on="click" data-av-analytics-label="{{label}}"></div></div>');
      var controller = $el.children().data('$avAnalyticsOnController');
      tester.$scope.label = 'Testing2';
      tester.$scope.$digest();
      spyOn(controller, 'onEvent').and.callThrough();

      $el.children().trigger('click');
      tester.flush();
      expect(controller.onEvent).toHaveBeenCalled();
      expect(avAnalytics.trackEvent).toHaveBeenCalledWith({ event: 'click', level: 'info', label: 'Testing2' });
    });
  });
}); /* global  inject, describe, beforeEach, it, expect, jasmine, spyOn */