'use strict';

var _angular = require('angular');

var _angular2 = _interopRequireDefault(_angular);

var _jquery = require('jquery');

var _jquery2 = _interopRequireDefault(_jquery);

var _tester = require('tester');

var _tester2 = _interopRequireDefault(_tester);

require('@uirouter/angularjs');

require('../');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('avSpacesBreadcrumbs', function () {

  var $location = void 0;

  var tester = new _tester2.default();

  beforeEach(function () {
    _angular2.default.mock.module('ui.router', 'availity', 'availity.ui');
  });

  tester.directive();

  beforeEach(inject(function (_$location_) {
    $location = _$location_;
  }));

  var $el = void 0;

  it('should render breadcrumbs when space ID is in scope', function () {

    tester.$httpBackend.expectGET(/\/api\/sdk\/platform\/v1\/spaces\/99999\?sessionBust=\d+/).respond(200, {
      'id': '99999',
      'name': 'Acme Texas'
    });

    $el = tester.compileDirective('<div av-spaces-breadcrumbs space-id="99999" page-name="La Pagina"></div>');
    tester.$httpBackend.flush();

    expect(_jquery2.default.trim($el.find('li:eq(1)').text())).toBe('Acme Texas');
  });

  it('should NOT render breadcrumbs when space ID is out of scope', function () {

    $el = tester.compileDirective('<div av-spaces-breadcrumbs page-name="La Pagina"></div>');
    expect(_jquery2.default.trim($el.find('li:eq(1)').text())).toBe('La Pagina');
  });

  it('should render breadcrumbs when space ID is in location query params', function () {

    tester.$httpBackend.expectGET(/\/api\/sdk\/platform\/v1\/spaces\/99999\?sessionBust=\d+/).respond(200, {
      'id': '99999',
      'name': 'Acme Texas'
    });

    $location.search('spaceId', '99999');

    $el = tester.compileDirective('<div av-spaces-breadcrumbs></div>');
    tester.$httpBackend.flush();

    expect(_jquery2.default.trim($el.find('li:eq(1)').text())).toBe('Acme Texas');
    expect(_jquery2.default.trim($el.find('a:eq(1)').attr('href'))).toBe('/public/apps/spaces/#/99999');
  });

  it('should render url from space when useSpaceUrl option set to true', function () {
    tester.$httpBackend.expectGET(/\/api\/sdk\/platform\/v1\/spaces\/99999\?sessionBust=\d+/).respond(200, {
      'id': '99999',
      'name': 'Acme Texas',
      'link': {
        'url': '/public/apps/my-application'
      }
    });

    $location.search('spaceId', '99999');

    $el = tester.compileDirective('<div av-spaces-breadcrumbs use-space-url="true"></div>');
    tester.$httpBackend.flush();

    expect(_jquery2.default.trim($el.find('a:eq(1)').attr('href'))).toBe('/public/apps/my-application');
  });
}); /* global beforeEach, expect, module, inject, describe, it*/