'use strict';

var _angular = require('angular');

var _angular2 = _interopRequireDefault(_angular);

var _tester = require('tester');

var _tester2 = _interopRequireDefault(_tester);

var _fixtures = require('./fixtures');

var _fixtures2 = _interopRequireDefault(_fixtures);

require('../');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* global beforeEach, afterEach, expect, module, describe, it*/

/**
 * Inspiration https://github.com/mgcrea/angular-strap/blob/v0.7.8/test/unit/directives/datepickerSpec.js
 */

describe('avDatepicker', function () {

  var avDatepickerConfig = null;
  var tester = new _tester2.default();
  var DEBOUNCE = void 0;

  beforeEach(function () {
    _angular2.default.mock.module('availity');
    _angular2.default.mock.module('availity.ui');
  });

  beforeEach(_angular2.default.mock.module(function (avDatepickerConfigProvider, AV_VAL) {

    avDatepickerConfig = avDatepickerConfigProvider;
    avDatepickerConfig.set({
      daysOfWeekDisabled: '0',
      datesDisabled: '1'
    });

    DEBOUNCE = AV_VAL.DEBOUNCE + 100;
  }));

  tester.directive();

  var $el = void 0;

  afterEach(function () {
    $el.data('datepicker').picker.remove();
  });

  it('should set default options', function () {

    $el = tester.compileDirective(_fixtures2.default.regular);

    var options = $el.data('$avDatepickerController').options;
    expect(options.autoclose).toBe(true);
    expect(options.todayHighlight).toBe(true);
    expect(options.format).toBe('mm/dd/yyyy');
    expect(options.forceParse).toBe(false);
  });

  it('should default options when supplied', function () {
    $el = tester.compileDirective(_fixtures2.default.regular);
    var options = $el.data('$avDatepickerController').options;
    expect(options.daysOfWeekDisabled).toBe('0');
    expect(options.datesDisabled).toBe('1');
  });

  it('should use attribute values over default values', function () {
    $el = tester.compileDirective(_fixtures2.default.disabledDates);
    var options = $el.data('$avDatepickerController').options;
    expect(options.datesDisabled).toBe('06');
  });

  it('should open on click', function () {
    tester.$scope.selectedDate = null;
    $el = tester.compileDirective(_fixtures2.default.regular);

    expect($el.data('datepicker').picker.is(':visible')).toBe(false);

    $el.focus().focus().click();

    expect($el.data('datepicker').picker.is(':visible')).toBe(true);
  });

  it('should initialize model with Date object', function () {

    tester.$scope.selectedDate = new Date(1986, 0, 22);

    $el = tester.compileDirective(_fixtures2.default.regular);
    tester.flush(DEBOUNCE);
    tester.$scope.$digest();

    expect($el.val()).toBe('01/22/1986');
  });

  it('should correctly ignore undefined date from MODEL', function () {
    tester.$scope.selectedDate = undefined;
    $el = tester.compileDirective(_fixtures2.default.regular);

    expect($el.val()).toBe('');
  });

  it('should correctly ignore null date from MODEL', function () {
    tester.$scope.selectedDate = null;
    $el = tester.compileDirective(_fixtures2.default.regular);

    expect($el.val()).toBe('');
  });

  it('should correctly ignore empty date from MODEL', function () {
    tester.$scope.selectedDate = '';
    $el = tester.compileDirective(_fixtures2.default.regular);

    expect($el.val()).toBe('');
  });

  it('should correctly parse formatted date from VIEW', function () {

    tester.$scope.selectedDate = null;
    $el = tester.compileDirective(_fixtures2.default.regular);

    var ngModel = $el.data('$ngModelController');
    ngModel.$setViewValue('01/20/1987');
    tester.flush(DEBOUNCE);
    tester.$scope.$digest();

    var date = tester.$scope.selectedDate;

    expect(date instanceof Date).toBe(true);
    expect(date.getFullYear()).toBe(1987);
    expect(date.getMonth()).toBe(0);
    expect(date.getDate()).toBe(20);
  });

  it('should correctly parse ALTERNATE formatted date', function () {

    tester.$scope.selectedDate = null;
    $el = tester.compileDirective(_fixtures2.default.format);

    var ngModel = $el.data('$ngModelController');
    ngModel.$setViewValue('13-01-1978');
    tester.flush(DEBOUNCE);
    tester.$scope.$digest();

    var date = tester.$scope.selectedDate;

    expect(date instanceof Date).toBe(true);
    expect(date.getFullYear()).toBe(1978);
    expect(date.getMonth()).toBe(0);
    expect(date.getDate()).toBe(13);
  });

  it('should not default to current date when input is invalid', function () {

    tester.$scope.selectedDate = null;
    $el = tester.compileDirective(_fixtures2.default.format);

    var ngModel = $el.data('$ngModelController');
    $el.focus().click(); // Yes call focus twice for IE8
    ngModel.$setViewValue('apple');
    $el.blur().blur().click();
    var date = ngModel.$viewValue;
    expect(date).toBe('apple');
  });
});