'use strict';

var _jquery = require('jquery');

var _jquery2 = _interopRequireDefault(_jquery);

var _angular = require('angular');

var _angular2 = _interopRequireDefault(_angular);

var _tester = require('tester');

var _tester2 = _interopRequireDefault(_tester);

var _template = require('./template.html');

var _template2 = _interopRequireDefault(_template);

require('../');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('AvModal', function () {

  var tester = new _tester2.default();
  var modal = void 0;
  var AvModal = void 0;

  beforeEach(function () {
    _angular2.default.mock.module('availity', 'availity.ui');
  });

  tester.directive();

  beforeEach(inject(function (_AvModal_) {

    _jquery2.default.support.transition = false;
    AvModal = _AvModal_;

    modal = new AvModal({
      template: _template2.default,
      scope: tester.$scope,
      container: '#sandbox'
    });

    tester.flush();
  }));

  it('should call $.fn.modal when modal.show()', function () {

    var old = _jquery2.default.fn.modal;
    var spy = _angular2.default.extend(spyOn(_jquery2.default.fn, 'modal'), old).and.callThrough();

    modal.show();

    tester.flush();
    tester.$scope.$digest();

    expect(spy).toHaveBeenCalledWith('show');
  });

  it('should destroy modal when scope is destroyed', function () {

    var spy = spyOn(modal, 'destroy').and.callThrough();
    tester.$scope.$destroy();
    expect(spy).toHaveBeenCalled();
  });

  it('should cleanup modal dom fragments when calling modal.destroy()', function () {

    expect(tester.sandboxEl.children('.modal').length).toBe(1);
    modal.destroy();
    tester.flush();
    expect(tester.sandboxEl.children('.modal').length).toBe(0);
  });

  it('should emit an event on show', function () {

    tester.$scope.$on('show.av.modal', tester.spy);
    modal.$element.modal('show');
    expect(tester.spy).toHaveBeenCalled();
  });

  it('should resolve promise on show', function () {

    modal.show();
    tester.flush();

    modal.show().then(tester.spy);
    tester.flush();

    expect(tester.spy).toHaveBeenCalled();
  });

  it('should resolve promise on toggle', function () {

    modal.show();
    tester.flush();

    modal.toggle().then(tester.spy);
    tester.flush();

    expect(tester.spy).toHaveBeenCalled();
  });

  it('should emit an event on shown and call `options.onShown` callback', function (done) {

    var spyOnShown = jasmine.createSpy('onShown');

    modal = new AvModal({
      template: _template2.default,
      scope: tester.$scope,
      container: '#sandbox',
      onShown: spyOnShown
    });

    tester.flush();

    tester.$scope.$on('shown.av.modal', function () {

      expect('shown triggered').toBeDefined();
      expect(spyOnShown).toHaveBeenCalled();
      done();
    });

    modal.$element.modal('show');
  });

  it('should emit event `hide.av.modal` on hide', function () {

    tester.$scope.$on('hide.av.modal', tester.spy);
    modal.$element.modal('hide');

    expect(tester.spy).toHaveBeenCalled();
  });

  it('should resolve promise on hide', function () {

    modal.show();
    tester.flush();

    modal.hide().then(tester.spy);
    tester.flush();

    expect(tester.spy).toHaveBeenCalled();
  });

  it('should resolve promise on hide when modal is NOT shown', function () {

    // Don't call modal.show() and promise should still resolve

    modal.hide().then(tester.spy);
    tester.flush();

    expect(tester.spy).toHaveBeenCalled();
  });

  it('should emit an event on hidden and call `options.onHidden` callback', function (done) {

    var spyOnHidden = jasmine.createSpy('onHidden');

    modal = new AvModal({
      template: _template2.default,
      scope: tester.$scope,
      show: true,
      onHidden: spyOnHidden
    });
    tester.flush();

    tester.$scope.$on('hidden.av.modal', function () {
      expect('hidden event').toBeDefined();
      expect(spyOnHidden).toHaveBeenCalled();
      done();
    });

    modal.$element.modal('hide');
  });

  it('should instantiate a controller if specified', function () {

    modal = new AvModal({
      template: _template2.default,
      scope: tester.$scope,
      controller: tester.spy
    });

    expect(tester.spy).toHaveBeenCalled();
  });

  it('should attach controller to scope if controllerAs is specified', function () {

    var controllerInstance = {};
    tester.spy.and.returnValue(controllerInstance);

    modal = new AvModal({
      template: _template2.default,
      scope: tester.$scope,
      controller: tester.spy,
      controllerAs: 'vm'
    });

    expect(tester.$scope.vm).toBe(controllerInstance);
  });

  it('should make locals available to be injected into the controller', function () {

    var controllerCalled = false;
    var expectedInjectedLocal = {};

    function MyController(localInjectedValue) {

      expect(localInjectedValue).toBe(expectedInjectedLocal);
      controllerCalled = true;
    }

    modal = new AvModal({
      template: _template2.default,
      scope: tester.$scope,
      controller: MyController,
      locals: {
        localInjectedValue: expectedInjectedLocal
      }
    });

    // Ensure the expect statement inside MyController was hit
    expect(controllerCalled).toBe(true);
  });
}); /* global jasmine, describe, beforeEach, it, spyOn, inject, expect */