'use strict';

var _jquery = require('jquery');

var _jquery2 = _interopRequireDefault(_jquery);

var _angular = require('angular');

var _angular2 = _interopRequireDefault(_angular);

var _tester = require('tester');

var _tester2 = _interopRequireDefault(_tester);

require('../');

require('../../validation');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('placeholder', function () {

  var $el = void 0;
  var placeholderSniffer = null;
  var $compile = void 0;
  var scope = void 0;
  var tester = new _tester2.default();

  var fixtures = {
    'default': '<input type="text" id="test" placeholder="testing">',
    'model': '<input type="text" name="model" data-ng-model="demo.data" placeholder="testing">',
    'testValue': '<input type="text" placeholder="testing" value="test">'
  };

  beforeEach(function () {
    _angular2.default.mock.module('ng.shims.placeholder');
    _angular2.default.mock.module('availity', function (avValProvider) {
      avValProvider.addRules({
        default: {
          lastName: {
            size: {
              min: 2,
              max: 10,
              message: 'Last name must be between 2 and 10 characters.'
            },
            required: {
              message: 'Last name is required.'
            }
          },
          dateFormat: {
            format: 'MM/DD/YYYY',
            message: 'Format needs to be MM/DD/YYYY'
          }
        }
      });
    });
    _angular2.default.mock.module('availity.ui');
  });

  tester.directive();

  beforeEach(inject(function ($injector, _placeholderSniffer_) {
    $compile = $injector.get('$compile');
    scope = $injector.get('$rootScope');
    scope.form = {};
    tester.$scope.demo = {};
    placeholderSniffer = _placeholderSniffer_;
    placeholderSniffer.hasPlaceholder = function () {
      return false; // force every browser to run the shim
    };
  }));

  it('should not dirty the value', function () {

    // why does this pass on travis but fails locally?
    // $el = tester.compileDirective(fixtures.default);
    // expect($el.val()).toEqual('testing');
    // expect($el.hasClass('empty')).toBe(true);

    var field = _angular2.default.element('<input type="text" id="test" placeholder="testing">');
    $compile(field)(scope);
    expect(field.val()).toBe('testing');
    expect(field.hasClass('empty')).toBe(true);
  });

  it('should not dirty the focused value', function () {
    $el = tester.compileDirective(fixtures.default);
    $el.triggerHandler('focus');
    expect($el.val()).toEqual('');
    expect($el.hasClass('empty')).toBe(false);
    $el.triggerHandler('blur');
  });

  it('should not dirty the model', function () {
    tester.$scope.demo = {
      data: ''
    };
    $el = tester.compileDirective(fixtures.model);
    tester.flush();
    expect(tester.$scope.demo.data).toEqual('');
  });

  it('should get value', function () {
    $el = tester.compileDirective(fixtures.testValue);
    expect($el.val()).toEqual('test');
  });

  describe('with validation', function () {

    beforeEach(function () {
      tester.$scope.demo = {};
      tester.$scope.demo.rules = 'default';

      var template = '\n        <form name="myForm" data-av-val-form="default">\n          <input data-ng-model="demo.lastName" name="lastName" type="text" data-av-val-field="lastName" placeholder="test"/>\n        </form>';

      $el = tester.compileDirective(template);
    });

    it('should be valid with model updated', function () {
      tester.$scope.myForm.lastName.$setViewValue('lastName');
      tester.$scope.$digest();

      expect(tester.$scope.myForm.lastName.$invalid).toBe(false);
      expect(tester.$scope.demo.lastName).toEqual('lastName');
    });

    it('should NOT be valid and model should NOT be updated', function () {
      tester.$scope.myForm.lastName.$setViewValue('1');
      tester.$scope.$digest();

      expect(tester.$scope.myForm.lastName.$invalid).toBe(true);
      expect(tester.$scope.demo.lastName).toBeUndefined();
    });
  });

  describe('with forms', function () {

    beforeEach(function () {

      tester.$scope.demo = {};
      tester.$scope.submit = jasmine.createSpy('submit');

      var template = '\n        <form name="myForm" data-ng-submit="submit()" id="myForm">\n          <input data-ng-model="demo.firstName" id="input1" name="firstName" type="text" placeholder="test"/>\n          <input data-ng-model="demo.lastName" id="input2" name="lastName" type="text" placeholder="test"/>\n          <input type="submit" id="submit" value="submit"/>\n        </form>';

      $el = tester.compileDirective(template);
    });

    it('should not dirty empty fields', function () {

      $el.triggerHandler('submit');
      tester.$scope.$digest();

      expect((0, _jquery2.default)('#input1').val()).toEqual('test');
      expect((0, _jquery2.default)('#input2').val()).toEqual('test');
      expect((0, _jquery2.default)('#input1').hasClass('empty')).toBe(true);
      expect((0, _jquery2.default)('#input2').hasClass('empty')).toBe(true);

      expect(tester.$scope.demo.firstName).toBeUndefined();
      expect(tester.$scope.demo.lastName).toBeUndefined();
      expect(tester.$scope.submit).toHaveBeenCalled();
    });

    it('should submit correct values', function () {

      (0, _jquery2.default)('#input1').val('Gary');
      (0, _jquery2.default)('#input2').val('Oak');
      (0, _jquery2.default)('#myForm').on('submit', function (e) {
        e.preventDefault();
        expect((0, _jquery2.default)('#input1').val()).toEqual('Gary');
        expect((0, _jquery2.default)('#input2').val()).toEqual('Oak');
      });
      (0, _jquery2.default)('#myForm').submit();
    });

    it('should be able to reset', function () {
      (0, _jquery2.default)('#input1').val('Gary');
      (0, _jquery2.default)('#input2').val('Oak');
      (0, _jquery2.default)('#myForm').on('submit', function (e) {
        e.preventDefault();
        expect((0, _jquery2.default)('#input1').val()).toEqual('');
        expect((0, _jquery2.default)('#input2').val()).toEqual('');
      });
      (0, _jquery2.default)('#myForm')[0].reset();
      (0, _jquery2.default)('#myForm').submit();
    });
  });
}); /* global describe, it, jasmine, expect, beforeEach, inject */