'use strict';

var _angular = require('angular');

var _angular2 = _interopRequireDefault(_angular);

require('../');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* global beforeEach, jasmine, spyOn, inject, expect, describe, it */
describe('AvTooltip Controller', function () {
  var _this = this;

  beforeEach(_angular2.default.mock.module('availity', 'availity.ui', function ($provide) {
    _this.mockElement = {
      on: jasmine.createSpy(),
      tooltip: jasmine.createSpy(),
      data: jasmine.createSpy()
    };

    _this.mockScope = {
      $on: jasmine.createSpy()
    };

    _this.mockAV_TOOLTIP = {
      name: 'bs.tooltip'
    };

    _this.mockTimeout = jasmine.createSpy();
    _this.mockAvTooltipConfig = {
      showDelay: 1247
    };

    $provide.value('$element', _this.mockElement);
    $provide.value('$scope', _this.mockScope);
    $provide.value('AV_TOOLTIP', _this.mockAV_TOOLTIP);
    $provide.value('$timeout', _this.mockTimeout);
    $provide.value('avTooltipConfig', _this.mockAvTooltipConfig);
  }));

  beforeEach(inject(function ($rootScope, $controller) {
    _this.$rootScope = $rootScope;
    _this.ctrl = $controller('AvTooltipController', { $scope: _this.mockScope });
  }));

  describe('class constructor', function () {
    it('should set options', function () {
      expect(_this.ctrl.options).toEqual(_this.mockAvTooltipConfig);
    });

    it('options should be a copy', function () {
      _this.mockAvTooltipConfig.something = 'now different';
      expect(_this.ctrl.options).not.toEqual(_this.mockAvTooltipConfig);
    });
  });

  describe('listeners method', function () {
    beforeEach(function () {
      _this.ctrl.listeners();
    });

    it('should set 4 listeners on element', function () {
      expect(_this.mockElement.on).toHaveBeenCalledTimes(4);
    });

    it('should set a listener on element for show', function () {
      expect(_this.mockElement.on.calls.argsFor(0)).toEqual(['show.bs.tooltip', jasmine.any(Function)]);
    });

    it('should set a listener on element for shown', function () {
      expect(_this.mockElement.on.calls.argsFor(1)).toEqual(['shown.bs.tooltip', jasmine.any(Function)]);
    });

    it('should set a listener on element for hide', function () {
      expect(_this.mockElement.on.calls.argsFor(2)).toEqual(['hide.bs.tooltip', jasmine.any(Function)]);
    });

    it('should set a listener on element for hidden', function () {
      expect(_this.mockElement.on.calls.argsFor(3)).toEqual(['hidden.bs.tooltip', jasmine.any(Function)]);
    });
  });

  describe('plugin method', function () {
    beforeEach(function () {
      _this.ctrl.plugin();
    });

    it('should set a listener on element for show', function () {
      expect(_this.mockElement.data).toHaveBeenCalledWith(_this.mockAV_TOOLTIP.name);
    });
  });

  describe('show method', function () {
    beforeEach(function () {
      _this.ctrl.show();
    });

    it('should set a listener on element for show', function () {
      expect(_this.mockElement.tooltip).toHaveBeenCalledWith('show');
    });
  });

  describe('hide method', function () {
    beforeEach(function () {
      _this.ctrl.hide();
    });

    it('should set a listener on element for show', function () {
      expect(_this.mockElement.tooltip).toHaveBeenCalledWith('hide');
    });
  });

  describe('toggle method', function () {
    beforeEach(function () {
      _this.ctrl.toggle();
    });

    it('should set a listener on element for show', function () {
      expect(_this.mockElement.tooltip).toHaveBeenCalledWith('toggle');
    });
  });

  describe('destroy method', function () {

    beforeEach(function () {
      _this.ctrl.$destroy();
    });

    it('should set a listener on element for show', function () {
      expect(_this.mockElement.tooltip).toHaveBeenCalledWith('destroy');
    });
  });

  describe('init method', function () {
    it('should call listeners', function () {
      var spy = spyOn(_this.ctrl, 'listeners');
      _this.ctrl.init();
      expect(spy).toHaveBeenCalledTimes(1);
    });

    describe('when show is true in the scope', function () {
      beforeEach(function () {
        _this.mockScope.show = true;
        _this.ctrl.init();
      });

      it('call $timeout twice', function () {
        expect(_this.mockTimeout).toHaveBeenCalledTimes(2);
      });

      it('call $timeout with 0', function () {
        expect(_this.mockTimeout.calls.argsFor(0)).toEqual([jasmine.any(Function), 0, false]);
      });

      describe('when delay.hide is not set in the scope', function () {
        beforeEach(function () {
          _this.ctrl.init();
        });

        it('call $timeout with the default delay', function () {
          expect(_this.mockTimeout.calls.argsFor(1)).toEqual([jasmine.any(Function), _this.mockAvTooltipConfig.showDelay, false]);
        });
      });

      describe('when delay.hide is set in the scope', function () {
        beforeEach(function () {
          _this.mockScope.delay = { hide: 5231 };
          _this.mockTimeout.calls.reset();
          _this.ctrl.init();
        });

        it('call $timeout with the delay provided', function () {
          expect(_this.mockTimeout.calls.argsFor(1)).toEqual([jasmine.any(Function), _this.mockScope.delay.hide, false]);
        });
      });
    });
  });
});