'use strict';

var _angular = require('angular');

var _angular2 = _interopRequireDefault(_angular);

var _tester = require('tester');

var _tester2 = _interopRequireDefault(_tester);

var _adapterBootstrap = require('./adapter-bootstrap.html');

var _adapterBootstrap2 = _interopRequireDefault(_adapterBootstrap);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('avValBootstrapAdapter', function () {

  var tester = new _tester2.default();

  beforeEach(function () {

    _angular2.default.mock.module('availity', 'availity.ui', function (avValProvider) {

      avValProvider.addRules({
        standard: {
          lastName: {
            size: {
              min: 2,
              max: 10,
              message: 'Last name must be between 2 and 10 characters.'
            },
            required: {
              'message': 'Last name is required.'
            }
          }
        }

      });
    });
  });

  tester.directive();

  var $form = null;
  var $el = null;
  var AV_BOOTSTRAP_ADAPTER = null;
  var DEBOUNCE = void 0;

  beforeEach(inject(function (_AV_BOOTSTRAP_ADAPTER_, _AV_VAL_) {

    AV_BOOTSTRAP_ADAPTER = _AV_BOOTSTRAP_ADAPTER_;
    DEBOUNCE = _AV_VAL_.DEBOUNCE + 100;

    $form = tester.compileDirective(_adapterBootstrap2.default);
    $el = $form.find('input[name="lastName"]');
  }));

  it('should NOT apply class .has-error to $pristine form', function () {
    expect($el.parents(AV_BOOTSTRAP_ADAPTER.CLASSES.FORM_GROUP).hasClass('has-error')).toBe(false);
  });

  it('should NOT apply class .has-error for valid input', function () {
    tester.$scope.mockForm.lastName.$setViewValue('lastName');
    tester.flush(DEBOUNCE);
    tester.$scope.$digest();
    expect($el.parents(AV_BOOTSTRAP_ADAPTER.CLASSES.FORM_GROUP).hasClass('has-error')).toBe(false);
    expect(tester.$scope.mockForm.lastName.$valid).toBe(true);
  });

  it('should apply class .has-error for invalid input', function () {

    tester.$scope.mockForm.lastName.$setViewValue('b');
    tester.flush(DEBOUNCE);
    tester.$scope.$digest();

    expect(tester.$scope.mockForm.lastName.$valid).toBe(false);
    expect($el.parents(AV_BOOTSTRAP_ADAPTER.CLASSES.FORM_GROUP).hasClass('has-error')).toBe(true);
    expect(tester.$scope.mockForm.$valid).toBe(false);
    expect($el.hasClass('ng-invalid')).toBe(true);
  });
}); /* global inject, beforeEach, expect, module, describe, it */