'use strict';

var _jquery = require('jquery');

var _jquery2 = _interopRequireDefault(_jquery);

var _angular = require('angular');

var _angular2 = _interopRequireDefault(_angular);

var _tester = require('tester');

var _tester2 = _interopRequireDefault(_tester);

var _field = require('./field.html');

var _field2 = _interopRequireDefault(_field);

require('../../datepicker');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('avValField', function () {

  var tester = new _tester2.default();
  var DEBOUNCE = void 0;

  beforeEach(function () {
    _angular2.default.mock.module('availity', 'availity.ui', function (avValProvider, AV_VAL) {

      avValProvider.addRules({
        default: {
          lastName: {
            size: {
              min: 2,
              max: 10,
              message: 'Last name must be between 2 and 10 characters'
            },
            required: {
              message: 'Last name is required'
            }
          },
          zip: {
            required: {
              message: 'Zip is required'
            }
          },
          dateFormat: {
            format: 'MM/DD/YYYY',
            message: 'Format needs to be MM/DD/YYYY'
          }
        }
      });

      DEBOUNCE = AV_VAL.DEBOUNCE + 100;
    });
  });

  tester.directive();

  var $el = void 0;

  beforeEach(function () {

    tester.$scope.demo = {};
    tester.$scope.demo.rules = 'default';
  });

  it('should be valid and model should updated with new value', function () {

    $el = tester.compileDirective(_field2.default);

    tester.$scope.mockForm.lastName.$setViewValue('lastName');

    tester.flush(DEBOUNCE);
    tester.$scope.$digest();

    expect(tester.$scope.mockForm.lastName.$invalid).toBe(false);
    expect(tester.$scope.demo.lastName).toBe('lastName');
  });

  it('should NOT be valid and model should NOT be updated', function () {

    $el = tester.compileDirective(_field2.default);

    tester.$scope.mockForm.lastName.$setViewValue('1');

    tester.flush(DEBOUNCE);
    tester.$scope.$digest();

    expect(tester.$scope.mockForm.lastName.$invalid).toBe(true);
    expect(tester.$scope.demo.lastName).toBeUndefined();
  });

  it('ngModel should be updated with invalid value when allowInvalid attribute is set to true', function () {

    $el = tester.compileDirective(_field2.default);

    tester.$scope.mockForm.invalidAllowed.$setViewValue('1');
    tester.flush(DEBOUNCE);
    tester.$scope.$digest();

    expect(tester.$scope.mockForm.invalidAllowed.$invalid).toBe(true);
    expect(tester.$scope.demo.invalidAllowed).toBe('1');
  });

  it('should have .has-error class on form group when options.show === true', function () {

    $el = tester.compileDirective(_field2.default);

    tester.$scope.mockForm.showOnLoad.$setViewValue('1');

    tester.flush(DEBOUNCE);
    tester.$scope.$digest();

    var formGroup = (0, _jquery2.default)('#showOnLoadFormGroup');
    expect(tester.$scope.mockForm.invalidAllowed.$invalid).toBe(true);
    expect(formGroup.hasClass('has-error')).toBeTruthy();
  });

  it('should have .has-error class on form-group', function () {

    $el = tester.compileDirective(_field2.default);

    tester.$scope.mockForm.lastName.$setViewValue('1');

    tester.flush(DEBOUNCE);
    tester.$scope.$digest();

    var formGroup = (0, _jquery2.default)('#lastNameFormGroup');
    expect(tester.$scope.mockForm.lastName.$invalid).toBe(true);
    expect(formGroup.hasClass('has-error')).toBeTruthy();
  });

  describe('events', function () {

    it('should validate on blur', function () {

      tester.$scope.demo.zip = null;

      $el = tester.compileDirective(_field2.default);

      $el.find('[name="zip"]').blur();
      tester.flush(DEBOUNCE);
      tester.$scope.$digest();
      expect(tester.$scope.mockForm.zip.$invalid).toBe(true);
    });

    it('should reset form', function () {

      $el = tester.compileDirective(_field2.default);

      tester.$scope.mockForm.lastName.$setViewValue('1');
      tester.flush(DEBOUNCE);
      tester.$scope.$digest();
      tester.$scope.$broadcast('av:val:reset');

      tester.$scope.$digest();
      tester.flush(DEBOUNCE);
      var formGroup = (0, _jquery2.default)('#lastNameFormGroup');

      expect(tester.$scope.mockForm.lastName.$invalid).toBe(true);
      expect(formGroup.hasClass('has-error')).toBeFalsy();
    });
  });

  describe('with avDatePicker', function () {

    it('should validate model using default format', function () {

      tester.$scope.demo.date = new Date(1986, 0, 22);

      $el = tester.compileDirective(_field2.default);

      tester.flush(DEBOUNCE);
      tester.$scope.$digest();

      expect(tester.$scope.mockForm.date.$invalid).toBe(false);
      expect(tester.$scope.mockForm.date.$viewValue).toBe('01/22/1986');
    });

    it('should not rollover invalid month values', function () {

      tester.$scope.demo.date = null;
      $el = tester.compileDirective(_field2.default);
      var $date = $el.find('#datez');

      var ngModel = $date.data('$ngModelController');
      ngModel.$setViewValue('15/04/1945');

      tester.flush(DEBOUNCE);
      tester.$scope.$digest();

      expect(tester.$scope.mockForm.date.$invalid).toBe(true);
    });
  });
}); /* global describe, it, beforeEach, expect, module */