'use strict';

var _angular = require('angular');

var _angular2 = _interopRequireDefault(_angular);

require('../form');

var _tester = require('tester');

var _tester2 = _interopRequireDefault(_tester);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('avForm', function () {

  var tester = new _tester2.default();

  var DEBOUNCE = void 0;
  beforeEach(function () {

    _angular2.default.mock.module('availity', function (avValProvider) {

      avValProvider.addRules({
        standard: {
          firstName: {
            size: {
              min: 2,
              max: 10,
              message: 'First name must be between 2 and 10 characters.'
            },
            required: {
              message: 'First name is required.'
            }
          },
          lastName: {
            size: {
              min: 2,
              max: 10,
              message: 'Last name must be between 2 and 10 characters.'
            },
            required: {
              message: 'Last name is required.'
            }
          }
        }
      });
    });

    _angular2.default.mock.module('availity.ui', function (_AV_VAL_) {
      // The framework adds a default debounce of ~800ms.  When running tests,
      // a tester.flush(X) must be called with a number greater than the default debounce
      DEBOUNCE = _AV_VAL_.DEBOUNCE + 100;
    });
  });

  tester.directive();

  var $el = void 0;

  beforeEach(function () {

    tester.$scope.submit = jasmine.createSpy('submit');

    tester.$scope.demo = {
      rules: 'standard'
    };

    var template = '\n    <form name="mockForm" ng-submit="submit()" av-val-form="demo.rules" >\n      <input ng-model="demo.firstName" name="firstName" type="text" av-val-field="firstName"/>\n      <input ng-model="demo.lastName" name="lastName" type="text" av-val-field="lastName"/>\n      <input ng-model="demo.invalidAllowed" name="invalidAllowed" type="text" av-val-field="lastName"/>\n      <button type="submit">login</button>\n    </form>';

    $el = tester.compileDirective(template);
  });

  it('should be $dirty', function () {

    tester.$scope.mockForm.lastName.$setViewValue('lastName');
    tester.flush(DEBOUNCE);
    tester.$scope.$digest();

    expect(tester.$scope.mockForm.$dirty).toBe(true);
    expect($el.hasClass('ng-dirty')).toBe(true);
  });

  it('should be $pristine', function () {
    expect(tester.$scope.mockForm.$pristine).toBe(true);
    expect($el.hasClass('ng-pristine')).toBe(true);
  });

  it('should NOT be valid and model should NOT be updated', function () {

    tester.$scope.mockForm.lastName.$setViewValue('1');
    tester.flush(DEBOUNCE);
    tester.$scope.$digest();

    expect(tester.$scope.mockForm.lastName.$invalid).toBe(true);
    expect(tester.$scope.demo.lastName).toBeUndefined();
  });

  it('should NOT be valid and model should be updated', function () {

    var template = '\n    <form name="mockForm" ng-submit="submit()" av-val-form="demo.rules" ng-model-options="{ allowInvalid: true }">\n      <input ng-model="demo.firstName" name="firstName" type="text" av-val-field="firstName"/>\n      <input ng-model="demo.lastName" name="lastName" type="text" av-val-field="lastName"/>\n      <input ng-model="demo.invalidAllowed" name="invalidAllowed" type="text" av-val-field="lastName"/>\n      <button type="submit">login</button> +\n    </form>';

    $el = tester.compileDirective(template);

    tester.$scope.mockForm.invalidAllowed.$setViewValue('1');
    tester.flush(DEBOUNCE);
    tester.$scope.$digest();

    expect(tester.$scope.mockForm.invalidAllowed.$invalid).toBe(true);
    expect(tester.$scope.demo.invalidAllowed).toBe('1');
  });

  describe('submit', function () {

    it('should prevent default action', function () {
      tester.$scope.mockForm.invalidAllowed.$setViewValue('1');
      tester.flush(DEBOUNCE);
      $el.triggerHandler('submit');
      tester.$scope.$digest();

      expect(tester.$scope.submit).not.toHaveBeenCalled();
    });

    it('should NOT prevent default action', function () {

      tester.$scope.mockForm.lastName.$setViewValue('lastName');
      tester.$scope.mockForm.firstName.$setViewValue('firstName');
      tester.$scope.mockForm.invalidAllowed.$setViewValue('lastName');
      tester.flush(DEBOUNCE);
      tester.$scope.$digest();

      $el.triggerHandler('submit');

      tester.$scope.$digest();

      expect(tester.$scope.submit).toHaveBeenCalled();
    });
  });
}); /* global describe, it, beforeEach, expect, module, jasmine*/